# DES03 - API Design

Thiết kế API: RESTful, versioning, documentation.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [RESTful API Design](DES03-BP01-RESTful-API-Design.md) | Principles và conventions cho REST API |
| BP02 | [API Documentation](DES03-BP02-API-Documentation.md) | Document API với OpenAPI/Swagger |

## Tham khảo

- REST API Design Rulebook
- Microsoft REST API Guidelines
- Google API Design Guide
